@@ -223,7 +223,7 @@ define('audit', {
 
 define('audit-level', {
   default: null,
-  type: ['info', 'low', 'moderate', 'high', 'critical', 'none', null],
+  type: [null, 'info', 'low', 'moderate', 'high', 'critical', 'none'],
   description: `
     The minimum level of vulnerability for \`npm audit\` to exit with
     a non-zero exit code.
@@ -1154,7 +1154,7 @@ define('long', {
 })
 
 define('maxsockets', {
-  default: Infinity,
+  default: 15,
   type: Number,
   description: `
     The maximum number of connections to use per origin (protocol/host/port
@@ -1389,6 +1389,7 @@ define('prefix', {
 
 define('preid', {
   default: '',
+  hint: 'prerelease-id',
   type: String,
   description: `
     The "prerelease identifier" to use as a prefix for the "prerelease" part
@@ -1659,7 +1660,8 @@ define('script-shell', {
   `,
   type: [null, String],
   description: `
-    The shell to use for scripts run with the \`npm run\` command.
+    The shell to use for scripts run with the \`npm exec\`,
+    \`npm run\` and \`npm init <pkg>\` commands.
   `,
   flatten (key, obj, flatOptions) {
     flatOptions.scriptShell = obj[key] || undefined
@@ -2042,7 +2044,9 @@ define('which', {
 define('workspace', {
   default: [],
   type: [String, Array],
+  hint: '<workspace-name>',
   short: 'w',
+  envExport: false,
   description: `
     Enable running a command in the context of the configured workspaces of the
     current project while filtering by running only the workspaces defined by
@@ -2060,6 +2064,7 @@ define('workspaces', {
   default: false,
   type: Boolean,
   short: 'ws',
+  envExport: false,
   description: `
     Enable running a command in the context of **all** the configured
     workspaces.
